<?php
/*
 * vim:set softtabstop=4 shiftwidth=4 expandtab:
 *
 * LICENSE: GNU Affero General Public License, version 3 (AGPL-3.0-or-later)
 * Copyright 2001 - 2022 Ampache.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

declare(strict_types=1);

namespace Ampache\Module\User;

use Ampache\MockeryTestCase;

class PasswordGeneratorTest extends MockeryTestCase
{
    private ?PasswordGenerator $subject;

    public function setUp(): void
    {
        $this->subject = new PasswordGenerator();
    }

    public function testGenerateReturnsRandomPasswordsWithFixedLength(): void
    {
        $length = 8;

        $result  = $this->subject->generate($length);
        $result2 = $this->subject->generate($length);

        static::assertSame(
            $length,
            mb_strlen($result)
        );

        static::assertNotSame(
            $result,
            $result2
        );
    }

    public function testGenerateReturnsRandomPasswordsWithVariableLength(): void
    {
        $result  = $this->subject->generate();

        static::assertTrue(
            in_array(
                mb_strlen(($result)),
                range(14, 20)
            )
        );
    }
}
