# Spotify Web API for PHP Documentation
There are a lot of things possible with the Spotify Web API and these pages exist to give you an overview of how to make the most out of them. Which methods and options are available, how to use them, and what to do when something goes wrong.

First, start by checking out the [Getting started guide](/docs/getting-started.md) before continuing with the examples below.

## Examples
* **Authorization**
    * [Obtaining an access token using the Authorization Code Flow](/docs/examples/access-token-with-authorization-code-flow.md)
    * [Obtaining an access token using the Client Credentials Flow](/docs/examples/access-token-with-client-credentials-flow.md)
    * [Obtaining an access token using the Proof Key for Code Exchange (PKCE) Flow](/docs/examples/access-token-with-pkce-flow.md)
    * [Refreshing access tokens](/docs/examples/refreshing-access-tokens.md)
    * [Working with scopes](/docs/examples/working-with-scopes.md)
* **Fetching data**
    * [Fetching information about albums](/docs/examples/fetching-album-information.md)
    * [Fetching information about artists](/docs/examples/fetching-artist-information.md)
    * [Fetching information about audiobooks](/docs/examples/fetching-audiobook-information.md)
    * [Fetching information about podcasts](/docs/examples/fetching-podcast-information.md)
    * [Fetching information about tracks](/docs/examples/fetching-track-information.md)
    * [Fetching Spotify featured content](/docs/examples/fetching-spotify-featured-content.md)
    * [Searching the Spotify catalog](/docs/examples/searching-the-spotify-catalog.md)
* **Managing users**
    * [Controlling user playback](/docs/examples/controlling-user-playback.md)
    * [Following artists, playlists, and users](/docs/examples/following-artists-playlists-and-users.md)
    * [Managing a user's library](/docs/examples/managing-user-library.md)
    * [Managing a user's playlists](/docs/examples/managing-user-playlists.md)
    * [Managing a user's profile](/docs/examples/managing-user-profiles.md)
* **Working with the API**
    * [Handling errors](/docs/examples/handling-errors.md)
    * [Setting custom cURL options](/docs/examples/setting-custom-curl-options.md)
    * [Setting options](/docs/examples/setting-options.md)

## Method Reference
A full method reference listing all public methods is [available here](/docs/method-reference/).
